% ----- example 5.1
% Simple Gibbs Sampling Example:
n=100; k=3;                    % set nobs and nvars
x = randn(n,k); b = ones(k,1); % generate data set
y = x*b + randn(n,1);
r = [1.0 1.0 1.0]';            % prior means
R = eye(k); T = eye(k);	       % prior variance          
Q = chol(inv(T)); q = Q*r;
b0 = (x'*x)\(x'*y);            % use ols as initial values
sige = (y-x*b0)'*(y-x*b0)/(n-k);	
xpx = x'*x; xpy = x'*y;        % calculate x'x, x'y only once
qpq = Q'*Q; qpv = Q'*q;        % calculate Q'Q, Q'q only once
ndraw = 1100; nomit = 100;     % set the number of draws     
bsave = zeros(ndraw,k);        % allocate storage for results
ssave = zeros(ndraw,1); 
tic;
for i=1:ndraw;                 % Start the sampling
 xpxi = inv(xpx + sige*qpq);
 b = xpxi*(xpy + sige*qpv);    % update b 
 b = norm_rnd(sige*xpxi) + b;  % draw MV normal with mean(b), var(b)
 bsave(i,:) = b';              % save b draws
 e = y - x*b; ssr = e'*e;      % update sige
 chi = chis_rnd(1,n);          % do chisquared(n) draw 
 sige = ssr/chi; 
 ssave(i,1) = sige;            % save sige draws
end;                           % End the sampling
toc;
bhat = mean(bsave(nomit+1:ndraw,:));  % calculate means and std deviations
bstd = std(bsave(nomit+1:ndraw,:)); tstat = bhat./bstd;
sighat = mean(ssave(nomit+1:ndraw,1));
tout = tdis_prb(tstat',n);     % compute t-stat significance levels
% set up for printing results
in.cnames = strvcat('Coefficient','t-statistic','t-probability');
in.rnames = strvcat('Variable','variable 1','variable 2','variable 3');
in.fmt = '%16.6f';
tmp = [bhat' tstat' tout];
fprintf(1,'Gibbs estimates \n'); % print results
mprint(tmp,in);
result = theil(y,x,r,R,T); % compare to Theil-Golberger estimates
prt(result);
