function [ out ] = estoutput( )
%ESTOUTPUT Creates estimation output structure filled with NaN
%   [OUT]=  ESTOUTPUT() creates estimation output structure filled with NaN
%
%   The structure will contain the following properties:
%   method = NaN;   % Estimation Method
%   method2 = NaN;  % Estimation Method 2 (Method for Panel Data)
%   y = NaN;        % Dependent variable data
%   X = NaN;        % Independent variable data
%   H = NaN;        % Instruments data
%   N = NaN;        % Total number of observations
%   n = NaN;        % Number of individuals
%   T = NaN;        % Number of time periods
%   k = NaN;        % Number of variables (including the constant term)
%   l = NaN;        % Number of instruments (IV estimations)
%   constant = NaN; % Equals 1 if the model has constant term
%   robust = NaN;   % Equals 1 if robust standard errors
%   coef = NaN;     % Estimated coefficientes
%   varcoef = NaN;  % Estimated covariance matrix of the coefficients
%   stderr = NaN;   % Estimated standard errors
%   yhat = NaN;     % Fitted values
%   res = NaN;      % Residual
%   resvar = NaN;   % Residual variance
%   statistic = NaN;    % Statistics of individual significance
%   df_statistic = NaN; % Degrees of freedom of the statistic of individual significance
%   p_statistic = NaN;  % p-value of the statistic of individual significance
%   jointsig = NaN;     % Statistic of joint significance
%   df_jointsig_n = NaN;% Degrees of freedom of the numerator of the statistic of joint significance
%   df_jointsig_d = NaN;% Degrees of freedom of the denominator of the statistic of joint significance
%   p_jointsig = NaN;   % p-value of the statistic of joint significance
%   r2 = NaN;       % R-square
%   adjr2 = NaN;    % Adjusted R-square
%   dvarnames = NaN;    % Dependent variables names
%   ivarnames = NaN;    % Independent variables names
%
%   AUTHOR:
%   Inmaculada C. lvarez
%   Javier Barbero
%   Jos L. Zofo
%
%   http://www.paneldatatoolbox.com
%
%   Version: 1.0
%   LAST UPDATE: 17, October, 2013
%

    out.method = NaN;   % Estimation Method
    out.method2 = NaN;  % Estimation Method 2 (Method for Panel Data)
    out.y = NaN;        % Dependent variable data
    out.X = NaN;        % Independent variable data
    out.H = NaN;        % Instruments data
    out.N = NaN;        % Total number of observations
    out.n = NaN;        % Number of individuals
    out.T = NaN;        % Number of time periods
    out.k = NaN;        % Number of variables (including the constant term)
    out.l = NaN;        % Number of instruments (IV estimations)
    out.constant = NaN; % Equals 1 if the model has constant term
    out.robust = NaN;   % Equals 1 if robust standard errors
    out.coef = NaN;     % Estimated coefficientes
    out.varcoef = NaN;  % Estimated covariance matrix of the coefficients
    out.stderr = NaN;   % Estimated standard errors
    out.yhat = NaN;     % Fitted values
    out.res = NaN;      % Residual
    out.resvar = NaN;   % Residual variance
    out.statistic = NaN;    % Statistics of individual significance
    out.df_statistic = NaN; % Degrees of freedom of the statistic of individual significance
    out.p_statistic = NaN;  % p-value of the statistic of individual significance
    out.jointsig = NaN;     % Statistic of joint significance
    out.df_jointsig_n = NaN;% Degrees of freedom of the numerator of the statistic of joint significance
    out.df_jointsig_d = NaN;% Degrees of freedom of the denominator of the statistic of joint significance
    out.p_jointsig = NaN;   % p-value of the statistic of joint significance
    out.r2 = NaN;       % R-square
    out.adjr2 = NaN;    % Adjusted R-square
    out.dvarnames = NaN;    % Dependent variables names
    out.ivarnames = NaN;    % Independent variables names


end

