function [ fig ] = estplot( est, type )
%ESTPLOT Plot results for the given estimation
%   fig = ESTPLOT( EST, TYPE ) plot results for the given estimation EST.
%
%   The following TYPE of plots are available
%   - 'fit': fitted and observed values
%   - 'res': residuals
%   - 'pfit': fitted and observed values for panel
%   - 'pres': residuals por panel
%
%   The function returns the handle of the created figure
%
%   AUTHOR:
%   Inmaculada C. lvarez
%   Javier Barbero
%   Jos L. Zofo
%
%   http://www.paneldatatoolbox.com
%
%   Version: 1.0
%   LAST UPDATE: 17, October, 2013
%

    % For panel plots
    
    Jbar = ones(est.T)./est.T;
    P = kron(eye(est.n),Jbar);
    
    switch(type)
        case 'fit'
            fig = figure;
            hold on
            plot(est.y,'b');
            plot(est.yhat,'r--');
            xlim([0 est.N]);
            xlabel('Observation');
            ylabel('Observed and fitted');
            title('Observed and fitted values');
            legend('Observed','Fitted','Location','Best');
            hold off
            
        case 'pfit'
            % Compute group means and get only one observation
            yhat = P * est.yhat;            
            yhat = yhat(1:est.T:end);
            y = P * est.y;
            y = y(1:est.T:end);    

            fig = figure;
            hold on
            plot(y,'b');
            plot(yhat,'r--');
            xlim([0 est.n]);
            xlabel('Observation');
            ylabel('Observed and fitted');
            title('Observed and fitted values');
            legend('Observed','Fitted','Location','Best');
            hold off
            
        case 'res'
            fig = figure;
            hold on
            plot(est.res,'b.');
            plot([0,est.N],[0,0],'k--');
            xlim([0 est.N]);
            xlabel('Observation');
            ylabel('Residuals');
            title('Residuals');
            hold off
            
        case 'pres'
            % Compute group means and get only one observation
            res = P * est.res;
            res = res(1:est.T:end);
            
            fig = figure;
            hold on
            plot(res,'b.');
            plot([0,est.n],[0,0],'k--');
            xlim([0 est.n]);
            xlabel('Observation');
            ylabel('Residuals');
            title('Residuals');
            hold off          
            
        otherwise
            eror('Plot %s not available', type)
    end
    
end

