function hausmanprint( estA, estB )
%HAUSMANPRINT Performs and print Hausman's test of specification
%   [H , P] = HAUSMANPRINT( ESTA, ESTB ) performs and print Hausman's test of
%   specification being ESTA and ESTB consistent under the null hypothesis,
%   and ESTA consisting under the alternative hypothesis. The value of the
%   test is returned in H and the p-vaue in P.
%
%   AUTHOR:
%   Inmaculada C. lvarez
%   Javier Barbero
%   Jos L. Zofo
%
%   http://www.paneldatatoolbox.com
%
%   Version: 1.0
%   LAST UPDATE: 17, October, 2013
%

    [H, p] = hausman(estA, estB);
    
    ktest = estA.k;
    
    if isnan(estA.method2)
        estAname = estA.method;
    else
        estAname = strcat(estA.method,'-',estA.method2);
    end
    
    if isnan(estB.method2)
        estBname = estB.method;
    else
        estBname = strcat(estB.method,'-',estB.method2);
    end
    
    stderrdif = sqrt(diag(estA.varcoef(1:ktest,1:ktest) - estB.varcoef(1:ktest,1:ktest)));
    
    estA = adddefivarnames(estA);
    
    fprintf('_________________________________________________________\n');
    fprintf('<strong>Hausman''s test of specification</strong>\n')
    disp(' ');
    
    fprintf('--------------------------------------------------------------\n');
    fprintf('                EstimationA  EstimationB    Coef    Std. Error\n');
    fprintf('    Varname     %11s %11s  Difference Difference \n', estAname, estBname);
    fprintf('--------------------------------------------------------------\n');
    for i=1:1:ktest-1
        %fprintf('%7.7s: %11f (%10f)',char(varnames(i)),pestre.coef(i),sqrt(pestre.varcoef(i,i)));
        fprintf('%14.14s  %11f %11f %10f %10.5f\n',char(estA.ivarnames(i)),estA.coef(i),estB.coef(i),estA.coef(i)-estB.coef(i), stderrdif(i));
    end
    fprintf('--------------------------------------------------------------\n');
    % disp(' ');
    fprintf('estA is consistent under H0 and H1 (estA = %s)\n',estAname)
    fprintf('estB is consistent under H0        (estB = %s)\n',estBname);
    fprintf('H0: coef(estA) - coef(estB) = 0 \n');
    fprintf('H1: coef(estA) - coef(estB) != 0 \n');
    %disp(' ');
    fprintf('      H = %7.7f \n',H);
    fprintf('p-value = %5.5f \n',p);
    fprintf('H is distributed as Chi2(%d) \n',ktest-1);
    
    disp(' ');


end