clear all
clc

% Example with Munnell (1990) data
disp('-----------------------------------------');
disp('            PANEL DATA MODELS            ');
disp('-----------------------------------------');

% Load data
load('MunnellData.mat')

y = log(gsp);
X = [log(pcap), log(pc), log(emp), unemp];
T = 17;

dvarnames = {'lgsp'};
ivarnames = {'lpcap', 'lpc', 'lemp', 'unemp'};

% OLS
regols = ols(y,X);
regols.dvarnames = dvarnames;
regols.ivarnames = ivarnames;
estprint(regols);

% Panel FE
regfe = panel(y, X, T, 'fe');
regfe.dvarnames = dvarnames;
regfe.ivarnames = ivarnames;
estprint(regfe);

% Panel BE
regbe = panel(y, X, T, 'be');
regbe.dvarnames = dvarnames;
regbe.ivarnames = ivarnames;
estprint(regbe);

% Panel RE
regre = panel(y, X, T, 're');
regre.dvarnames = dvarnames;
regre.ivarnames = ivarnames;
estprint(regre);

% Hausman test
hausmanprint(regfe, regre);

% Panel FE Robust
regfer = panel(y, X, T, 'fe', 'robust');
regfer.dvarnames = dvarnames;
regfer.ivarnames = ivarnames;
estprint(regfer);

% Panel RE Robust
regrer = panel(y, X, T, 're', 'robust');
regrer.dvarnames = dvarnames;
regrer.ivarnames = ivarnames;
estprint(regrer);


disp('-----------------------------------------');
disp('    INSTRUMENTAL PANEL DATA MODELS       ');
disp('-----------------------------------------');

% Example with Cigar data. Baltagi and Levin (1992) and Baltagi, Griffin and Xiong (2000)
clear all

% Load data
load('CigarData.mat')


y = log(c);
X = [log(price), log(ndi), log(pimin)];
H = [log(ndi_1), log(pimin_1), log(ndi), log(pimin)];
T = 29;

dvarnames = {'lc'};
ivarnames = {'lprice', 'lndi', 'lpimin'};

regfe = panel(y, X, T, 'fe');
regfe.dvarnames = dvarnames;
regfe.ivarnames = ivarnames;
estprint(regfe);

% IV Panel FE
regivfe = ivpanel(y, X, H, T, 'fe');
regivfe.dvarnames = dvarnames;
regivfe.ivarnames = ivarnames;
estprint(regivfe);

% IV Panel BE
regivbe = ivpanel(y, X, H, T, 'be');
regivbe.dvarnames = dvarnames;
regivbe.ivarnames = ivarnames;
estprint(regivbe);

% IV Panel RE
regivre = ivpanel(y, X, H, T, 're');
regivre.dvarnames = dvarnames;
regivre.ivarnames = ivarnames;
estprint(regivre);

% IV Panel Error components
regivec = ivpanel(y, X, H, T, 'ec');
regivec.dvarnames = dvarnames;
regivec.ivarnames = ivarnames;
estprint(regivec);

disp('-----------------------------------------');
disp('       SPATIAL PANEL DATA MODELS         ');
disp('-----------------------------------------');

% Example with Munnell (1990) data. Spatial
clear all

% Load data
load('MunnellData.mat')

y = log(gsp);
X = [log(pcap), log(pc), log(emp), unemp];
L = [ ];
T = 17;

dvarnames = {'lgsp'};
ivarnames = {'lpcap', 'lpc', 'lemp', 'unemp'};

load('MunnellW.mat');

W = kron(W, eye(T));

% S2SLS
regs2sls = s2sls(y,X, pcap, W);
regs2sls.dvarnames = dvarnames;
regs2sls.ivarnames = ivarnames;
estprint(regs2sls);

% Spatial Panel FE
regsfe = spanel(y, X, L, W, T, 'fe');
regsfe.dvarnames = dvarnames;
regsfe.ivarnames = ivarnames;
estprint(regsfe);

% Spatial Panel BE
regsbe = spanel(y, X, L, W, T, 'be');
regsbe.dvarnames = dvarnames;
regsbe.ivarnames = ivarnames;
estprint(regsbe);

% Spatial Panel RE
regsre = spanel(y, X, L, W, T, 're');
regsre.dvarnames = dvarnames;
regsre.ivarnames = ivarnames;
estprint(regsre);

% Spatial Panel EC
regsec = spanel(y, X, L, W, T, 'ec');
regsec.dvarnames = dvarnames;
regsec.ivarnames = ivarnames;
estprint(regsec);

% Spatial Panel SEC BEST
regsecb = spanel(y, X, L, W, T, 'sec-b');
regsecb.dvarnames = dvarnames;
regsecb.ivarnames = ivarnames;
estprint(regsecb);


